<?

/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
/* (c) 2000 Fabio Molinari (fabio.m@mclink.it) */

////////////////////////////////////////////////////////////
// "Shared" variables
////////////////////////////////////////////////////////////

// With regard to the following variables:
// each locale must include them from all the other locales...
// this makes the locales not totally independent of each other :(
$Choose_italian_language = "Mostra sito in lingua Italiana";
$Choose_english_language = "Go to the English version of the site";
//

$Home_Page = "Home page";
$Administration = "Administration";
$Login = "Login";
$Logout = "Logout";
$Username = "Username";
$Password = "Password";
$Password_Confirm = "Password (confirm)";
$Change_Password = "Change Password";
$Edit = "Edit";
$Delete = "Delete";
$Remove = "Remove";
$Total = "Total";
$Delivery = "Delivery";
$Cash_On_Delivery = "Cash On Delivery";
$Credit_Card = "Credit Card";
$Category = "Category";
$Categories_Browsing = "Categories Browsing";
$Categories = "Categories";
$The_category = "The category";
$Brand = "Brand";
$Brands = "Brands";
$The_brand = "The brand";
$The_IVA_Percentual = "The IVA percentual";
$Product = "Product";
$Products = "Products";
$The_product = "The product";
$Add_Product = "Add Product";
$Delete_Product = "Delete Product";
$Edit_Product = "Edit Product";
$Items = "items";
$Add_Subcategory = "Add Subcategory";
$Add_Brand = "Add Brand";
$Add_IVA = "Add IVA";
$back = "back";
$BACK = "BACK";
$Address = "Address";
$Number = "Number";
$City = "City";
$State = "State";
$Zip_Code = "Zip Code";
$Phone = "Phone";
$Fax = "Fax";
$MobilePhone = "Mobile Phone";
$Order_Details = "Order Details";
$Price = "Price";
$Weight = "Weight";
$Total_weight = "Total weight";
$Qty = "Qty";
$Sub_Total = "Sub Total";
$Grand_Total = "Grand Total";
$Payment_Methods = "Payment Methods";
$Add_to_cart = "+ Add to cart";
$Add_to_Shopping_Cart = "+ Add to Shopping Cart";
$Image = "Image";
$Notes = "Notes";
$Our_Notes = "Our Notes";
$Change_Settings = "Change Settings";
$First_Name = "First Name";
$Last_Name = "Last Name";
$Fiscal_Code = "Fiscal Code";
$E_mail = "E-mail";
$Import_Button_Label = "Import";
$Reset_Form = "Reset";

////////////////////////////////////////////////////////////
// Top level scripts
////////////////////////////////////////////////////////////

$login_failed = "Login failed, please try again";

////////////////////////////////////////////////////////////
// Top level templates
////////////////////////////////////////////////////////////

$footer_message = $CFG->myname . " \"<i>Electronic Store - Commercio elettronico</i>\"";
$Errors = "Errors";
$Contact_us = "Contact us !";
$Signup_Italy = "Signup (Italy)";
$Signup_non_Italy = "Signup (outside of Italy)";
$Enterprises_Signup = "Enterprises Signup";
$Shopping = "Shopping";
$Purchase_Now = "Purchase Now";
$Search_the_Catalog = "Search the Catalog";
$At_least_a_word = "At least a word";
$All_the_words = "All the words";
$Case_Sensitive = "Case Sensitive";
$Search_excl = "Search !";
$Insufficient_Privileges = "Insufficient Privileges";
$PgMarket_Login = $CFG->myname . " Login";
$PgMarket_Login_Page = $CFG->myname . ": Login Page";
$sign_up_for_an_account_now = "If you do not already have an account, please sign up for an account now:";
$dont_login_back_to_home_page = "If you do not wish to login yet, <a href=\"".$CFG->wwwroot."\">click here</a> to return to the home page.";
$Special_Products = "Special Products";

////////////////////////////////////////////////////////////
// admin scripts
////////////////////////////////////////////////////////////

$Add_User = "Add User";
$Categories_Management = "Category Management";
$C_Import_Categories = "Import categories";
$Brands_Management = "Brands Management";
$C_Import_Brands = "Import Brands";
$C_Import_IVA = "Import IVA percentuals";
$IVA_Management = "IVA Management";
$Orders_Log_ca = "Orders Log - Cash On Delivery";
$Orders_Log_cc = "Orders Log - Credit Card";
$Products_Management = "Products Management";
$C_Import_Products = "Import products";
$Save_Changes = "Save Changes";
$Users_Admin = "Users Management";
$U_Import_Users = "Import users";
$_Import_File = "File to be Imported:";
$Import_Images_Button_Label = "Importa Immagini";
$C_Import_Images = "Import Images";
$End_Import = "Import Completed.";

////////////////////////////////////////////////////////////
// admin templates
////////////////////////////////////////////////////////////

$Parent = "Parent";
$Name = "Name";
$Description = "Description";
$Extended_Description = "Extended Description";
$Discount = "Discount";
$Starting_from = "starting from";
$C_Add_Category = "[+C] Add Category";
$C_Add_Brand = "[+C] Add Brand";
$C_Add_IVA = "[+C] Add IVA percentual";
$C_Add_Product = "[+P] Add Product";
$Action = "Action";
$User = "User";
$The_user = "The user";
$data_have_been_updated = "data have been updated";
$has_been_added_female_singular = "has been added";
$has_been_added_male_singular = "has been added";
$has_been_updated_female_singular = "has been updated";
$has_been_updated_male_singular = "has been updated";
$has_been_deleted_female_singular = "has been deleted";
$has_been_deleted_male_singular = "has been deleted";
$All_the_products_and_sub_categories_belonging_to = "All the products and sub-categories belonging to";
$have_been_reassigned_to_male_plural = "have been reassigned to";
$actually_its_name_is_female_singular = "actually its name is";
$actually_its_value_is_female_singular = "actually its value is";
$Add_a_subcategory_under = "Add a subcategory under";
$Add_a_product_under = "Add a product under";
$Edit_this_category = "Edit this category";
$Edit_this_brand = "Edit this brand";
$Edit_this_IVA = "Edit this IVA percentual";
$admin_footer_message = $CFG->myname . " \"<i>Electronic Store - Commercio elettronico</i>\"";
$Brand_reset_for_products = "The Brand has been reset for all products of that brand";
$IVA_reset_for_products = "The IVA percentual has been reset for all products with that IVA percentual";
$Users = "Users";
$Edit_this_order = "Edit this order";
$Delete_this_order = "Delete this order";
$Order = "Order";
$Orders = "Orders";
$The_order = "The order";
$Sent = "Sent";
$Paid = "Paid";
$Ordered = "Ordered";
$Ordered_By = "Ordered By";
$Amount = "Amount";
$Customer_Info = "Customer Info";
$Enterprise_Id_N = "Enterprise Id. N.";
$ID = "ID";
$Current_Price = "Current Price";
$Purchase_Price = "Purchase Price";
$Order_Status = "Order Status";
$ID_and_Status = "ID - Status";
$Status = "Status";
$Cust_Info = "Cust. Info";
$Details = "Details";
$Special = "On Special";
$Normal = "Normal";
$Edit_this_product = "Edit this product";
$View_product_details = "View product details";
$Privilege = "Privilege";
$Enterprise_Name = "Enterprise Name";
$Enterprise_identification_number = "Enterprise identification number";
$Auth_data_handling_az = "Auth. data h.";
$Auth_data_handling_pf = "Auth. pers. data h.";
$Accept_advert_matherial = "Accept. advert. math.";
$Registration_Date = "Reg. Date";
$Authorization_for_data_handling_az = "Authorization for data handling";
$Authorization_for_data_handling_pf = "Authorization for personal data handling";
$Acceptance_of_advertising_matherial = "Acceptance of advertising matherial";
$U_Add_User = "[+U] Add User";
$U_Add_Enterprise_User = "[+U] Add Enterprise User";
$Data_handl = "Data handl.";
$Advert = "Advert.";
$Reset_password_for = "Reset password for";
$Change_password_for = "Change password for";
$Edit_this_user = "Edit this user";
$Email_this_user = "Email this user";

////////////////////////////////////////////////////////////
// shopping scripts
////////////////////////////////////////////////////////////

$Cart = "Cart";
$Shopping_Cart = "Shopping Cart";
$Checkout = "Checkout";
$Order_Completed_Successfully = "Order Completed Successfully";
$Product_Details = "Product Details: ";
$Product_Not_Found = "Product Not Found";
$Shopping_Catalog = "Shopping Catalog";
$Unable_To_Complete_The_Order = "Unable to Complete The Order";

////////////////////////////////////////////////////////////
// shopping templates
////////////////////////////////////////////////////////////

$None_Female_Singular = "None";
$None_Male_Singular = "None";
$Product_not_found = "Product not found";
$Sorry_product_not_found = "Sorry, the product you are looking for was not found on file.  Please try our <a href=\"".$CFG->wwwroot."/shopping/\">shopping catalog</a> to find what you are looking for.";
$Purchase_Confirmation = "Purchase Confirmation";
$Your_shopping_cart_is_empty = "Your shopping cart is empty, <a href=\"".$CFG->wwwroot."/shopping/\">see the product catalog</a>.";
$Billing_Details = "Billing Details";
$Date = "Date";
$Bill_to = "Bill to";
$Contact = "Contact";
$Comments_and_Special_Instructions = "Comments / Special Instructions";
$Step_1_Enter_Billing_Information = "Step 1. Enter Billing Information";
$Customer = "Customer";
$Phone_Contact = "Phone Contact";
$Step_2_Comments_and_Special_Instructions = "Step 2. Comments / Special Instructions";
$Next_Step = "Next Step";
$Search_Results = "Search Results";
$on = "on";
$pages = "pages";
$Your_Shopping_Cart_Contains = "Your Shopping Cart Contains";
$Continue_Shopping = "Continue Shopping";
$Recalculate_Cart = "Recalculate Cart";
$Empty_the_Cart = "Empty the Cart";

////////////////////////////////////////////////////////////
// users scripts
////////////////////////////////////////////////////////////

$Password_Change_Successful = "Password Change Successful";
$Settings_Change_Successful = "Settings Change Successful";
$Signup = "Signup";
$Signup_Successful = "Signup Successful";
$Contact_Us = "Contact Us via E-mail";
$Contact_Successful = "E-mail Successfully Sent";

////////////////////////////////////////////////////////////
// users templates
////////////////////////////////////////////////////////////

$Min_Username_Length = "(at least ". $SESSION["username_length_min"] . " characters)";
$Old_Password = "Old Password";
$New_Password = "New Password";
$Confirm_Password = "Confirm Password";
$I_agree_with_the_usage_of_the_presently_given_data = "I agree with the usage of the presently given data";
$I_accept_to_receive_advertising_matherial = "I accept to receive advertising matherial";
$I_agree_with_the_usage_of_my_personal_data = "I agree with the usage of my personal data";
$appoggio = return_star();
$Please_fill_out_this_contact_form = "Please fill out this contact form, note that all fields labeled through an asterisk (" . $appoggio . ") are mandatory.";
$First_and_Last_Name = "First and Last Name<br>(or Enterprise Name)";
$Message = "Message";
$Send = "Send";

////////////////////////////////////////////////////////////
// ERROR MESSAGES
////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////
// signup, contact us
////////////////////////////////////////////////////////////

$the_username = "The Username";
$already_exists = " is already used";

$empty_username = "Please specify the Username";
$username_too_long = "Username too much long: ".$SESSION["username_length"]." characters max";
$username_too_short = "Username too much short: ".$SESSION["username_length_min"]." characters min";
$not_valid_username = "Username not valid: please use only alphanumeric characters";

$passwords_do_not_match = "Passwords do not match";
$empty_password = "Please specify the Password";
$please_enable_javascript =
"<b>
For security reasons, to purchase products in our virtual store,
the use of JavaScript is required.
<p>
The JavaScript language, apart from providing functionalities
very useful for the Web software development, allows to crypt the passwords,
hence it offers much more security to this store's users.
<p>
Hence, to buy products in our virtual store, a browser supporting JavaScript
is required, as Netscape or Explorer, for example.
If you are using a browser supporting JavaScript but you have disabled
such support, please edit your preferences in order to enable JavaScript.
<p>
Note: with default options, JavaScript is enabled on Netscape and Explorer.
</b><br><br>";

$empty_firstname = "Please specify the First Name";
$firstname_too_long = "First Name too much long: ".$SESSION["firstname_length"]." characters max";

$empty_ragionesociale = "Please specify the Ragione Sociale";
$ragionesociale_too_long = "Ragione Sociale too much long: ".$SESSION["firstname_length"]." characters max";

$empty_lastname = "Please specify your Last Name";
$lastname_too_long = "Last Name too much long: ".$SESSION["lastname_length"]." characters max";

$empty_name = "Please specify the Name";
$name_too_long = "Name too much long: ".$SESSION["name_length"]." characters max";

$empty_fiscalcode = "Please specify the Fiscal Code";
$bad_fiscalcode_length = "Bad Fiscal Code lenght: the Fiscal Code must consist of ".$SESSION["fiscalcode_length"]." alfanumeric characters";
$not_valid_fiscalcode = "Fiscal Code not valid";

$empty_partitaiva = "Please specify the Enterprise identification number";
$bad_partitaiva_length = "Bad Enterprise identification number lenght: the Enterprise identification number must consist of ".$SESSION["partitaiva_length"]." ciphers";
$not_valid_partitaiva = "Enterprise identification number not valid";

$empty_address = "Please specify the address";
$address_too_long = "Address too much long: ".$SESSION["address_length"]." characters max";

$number_too_long = "Number too much long: ".$SESSION["number_length"]." characters max";

$empty_city = "Please specify the city";
$city_too_long = "City too much long: ".$SESSION["city_length"]." characters max";

$empty_state = "Please specify the state";
$state_too_long = "State too much long: ".$SESSION["state_length"]." characters max";

$empty_zip_code = "Please specify the Zip Code";
$zip_code_is_zero = "The Zip Code must be greater than zero";
$zip_code_notint = "The Zip Code entry must contain an integer number: only ciphers, not any other character";
$zip_code_length_is_wrong = "The Zip Code must consist of exactly " . $SESSION["zip_code_length"] . " ciphers";

$empty_phone = "Please specify the phone number";
$phone_too_long = "Phone number too much long: ".$SESSION["phone_length"]." characters max";
$phone_too_short = "Phone number too much short: ".$SESSION["phone_length_min"]." characters min";
$not_valid_phone = "Phone number not valid; only cyphers, spaces, +-()/ are allowed characters";

$fax_too_long = "Fax number too much long: ".$SESSION["fax_length"]." characters max";
$fax_too_short = "Fax number too much short: ".$SESSION["fax_length_min"]." characters min";
$not_valid_fax = "Fax number not valid; only cyphers, spaces, +-()/ are allowed characters";

$mobilephone_too_long = "Mobile Phone number too much long: ".$SESSION["mobilephone_length"]." characters max";
$mobilephone_too_short = "Mobile Phone number too much short: ".$SESSION["mobilephone_length_min"]." characters min";
$not_valid_mobilephone = "Mobile Phone number not valid; only cyphers, spaces, +-()/ are allowed characters";

$empty_email = "Please specify the E-mail address";
$email_too_long = "E-mail address too much long: ".$SESSION["email_length"]." characters max";
$not_valid_email = "E-mail address not valid";
//$the_email_address = "The E-mail address";
//$email_not_on_file = "The specified email address is not on file";

$notes_too_long = "Notes too much long: ".$SESSION["notes_length"]." characters max";
$ournotes_too_long = "Notes too much long in the field \"" . $Our_Notes . "\": ".$SESSION["ournotes_length"]." characters max";
$empty_message = "You did not write any message";
$message_too_long = "Message too much long: ".$SESSION["message_length"]." characters max";

////////////////////////////////////////////////////////////
// purchase now
////////////////////////////////////////////////////////////

$empty_customer = "You did not specify the Customer";
$appoggio = $SESSION["firstname_length"] + $SESSION["lastname_length"] + 1;
$customer_too_long = "Customer too much long: " . $appoggio . " characters max";
$empty_contact = "You did not specify a Phone to contact you";
$contact_too_long = "Contact Phone number too much long: ".$SESSION["phone_length"]." characters max";
$contact_too_short = "Contact Phone number too much short: ".$SESSION["phone_length_min"]." characters min";
$not_valid_contact = "Contact Phone number not valid";
$comments_too_long = "Comments too much long: ".$SESSION["comments_length"]." characters max";

////////////////////////////////////////////////////////////
// change password
////////////////////////////////////////////////////////////

$no_old_password = "You did not specify your old password";
$old_password_not_valid = "Your old password is not valid";
$no_new_password = "You did not specify your new password";
$no_new_password2 = "You did not confirm your new password";
$new_passwords_dont_match = "Your new passwords do not match";

////////////////////////////////////////////////////////////
// add and update category
////////////////////////////////////////////////////////////

$empty_category_name = "The category name is empty; please fill it";
$category_name_too_long = "Category Name too much long: ".$SESSION["category_name_length"]." characters max";
$category_description_too_long = "Category Description too much long: ".$SESSION["category_description_length"]." characters max";

$priv_too_long = "Privilege too much long: ".$SESSION["priv_length"]." characters max";
$not_valid_priv = "Privilege not valid: please use only alphanumeric characters";

$Err_ImpCat = ": the Parent Category doesn't exist - '";

////////////////////////////////////////////////////////////
// add and update brand
////////////////////////////////////////////////////////////

$empty_brand_name = "The brand name is empty; please fill it";
$brand_name_too_long = "Brand Name too much long: ".$SESSION["brand_name_length"]." characters max";
$brand_description_too_long = "Brand Description too much long: ".$SESSION["brand_description_length"]." characters max";

$Err_ImpBrand = ": the Brand doesn't exist - '";
$Err_ImpIVA = ": the IVA doesn't exist - '";

////////////////////////////////////////////////////////////
// add and update product
////////////////////////////////////////////////////////////

$product_id_is_empty = "The ID entry is empty; please fill it";
$product_id_wspace = "The ID <b><? pv($HTTP_POST_VARS[product_id]) ?></b> contains spaces. Please don't use spaces in product IDs";
$product_id_wampersand = "The ID <b><? pv($HTTP_POST_VARS[product_id]) ?></b> contains the character \"&amp;\". Please don't use this character in product IDs";
$product_id_wquestionm = "The ID <b><? pv($HTTP_POST_VARS[product_id]) ?></b> contains the character \"?\". Please don't use this character in product IDs";
$product_id_too_long = "Product ID too much long: ".$SESSION["product_id_length"]." characters max";
$the_product_id = "The product ID ";

$empty_product_name = "The product Name is empty; please fill it";
$product_name_too_long = "Product Name too much long: ".$SESSION["product_name_length"]." characters max";

$empty_price = "Please specify the Price";
$price_is_zero = "The Price must be greater than zero";
$price_notint = "The Price entry must contain an integer number: only ciphers, not any other character";
$price_notfloat = "The Price entry must contain a float number: only ciphers and optionally a dot, not any other character";

$not_valid_iva = "IVA not valid";
$iva_not_between_0_and_100 = "The IVA is not between 0 and 100";

$discount_not_completely_defined = "If you want to discount the product, you have to fill both the fields \"" . $Discount . "\" and \"" . $Starting_from . "\"; if you do not want to discount the product, please leave empty both the fields";
$not_valid_discount = "Discount not valid";
$discount_not_between_0_and_100 = "The Discount is not between 0 and 100";
$discqty_notint = "The \"" . $Starting_from . "\" entry is not an integer number: only ciphers, not any other character";
$discqty_is_negative = "The \"" . $Starting_from . "\" entry can not be a negative number";
$discqty_is_too_large = "The \"" . $Starting_from . "\" entry is too large: " . $SESSION["discqtymax"] . " max";

$empty_weight = "Please specify the Weight";
$not_valid_weight = "Weight not valid";
$weight_is_zero = "The Weight must be greater than zero";
$weight_over_max = "Weight too large: " . $SESSION["weightmax"] . " " . $weightunity . " max";

$on_special_empty = "The \"" . $Special . "\" entry is empty; please fill it";
$on_special_notint = "The \"" . $Special . "\" entry must contain an integer number: only ciphers, not any other character";

$product_description_too_long = "Product Description too much long: ".$SESSION["product_description_length"]." characters max";
$product_extended_description_too_long = "Product Extended Description too much long: ".$SESSION["product_extended_description_length"]." characters max";

$appoggio = floor ($SESSION["max_file_size_images"] / 1024);
$no_product_image_chosen = "No new image has been chosen to represent the product, or the submitted image is too large: " . $appoggio . " bytes max";
$image_upload_failed = "Image upload failed";
$unsupported_image_type = "Unsupported image type";

////////////////////////////////////////////////////////////
// advanced search
// prefix table: L = left	R = right
//		M = male	F = female
//		S = singular	P = plural
////////////////////////////////////////////////////////////

$there_are_errors = "There are errors in the submitted items";

$AdvancedSearch = "Advanced Search";

//$Less_or_Equal = "&le";
$min = "min &nbsp;";
$max = "&nbsp; max";
//$Subset_or_Equal = "&sube";
$Subset_or_Equal = "";

////////////////////////////////////////////////////////////
// Math symbols (only for Browser with full Html
// entities support (like Mozilla Mxx))
// or, maybe, it's only a matter of font ?
// $LMS_Less_or_Equal = "&le;";
// $LMP_Less_or_Equal = "&le;";
// $LFS_Less_or_Equal = "&le;";
// $LFP_Less_or_Equal = "&le;";
// $RMS_Less_or_Equal = "&le;";
// $RMP_Less_or_Equal = "&le;";
// $RFS_Less_or_Equal = "&le;";
// $RFP_Less_or_Equal = "&le;";
// $M_Subset_or_Equal = "&sube;";
// $F_Subset_or_Equal = "&sube;";
////////////////////////////////////////////////////////////
$LMS_Less_or_Equal = "";
$LMP_Less_or_Equal = "";
$LFS_Less_or_Equal = "";
$LFP_Less_or_Equal = "";
$RMS_Less_or_Equal = "included between";
$RMP_Less_or_Equal = "included between";
$RFS_Less_or_Equal = "included between";
$RFP_Less_or_Equal = "included between";
$M_Subset_or_Equal = "contained in";
$F_Subset_or_Equal = "contained in";

////////////////////////////////////////////////////////////

$connection_error = "Connection error to the database";

$submission_to_banca_sella = "Credit Card payment through Banca Sella";
$no_more_passwordric = "At the present time, all the passwords available for interfacing with E-Commerce Online have been used, hence at this moment it is impossible to pay through the Credit Card";

?>
